# Webkit text bug

Small font sizes look bad when zoomed to in Webkit. There is a way to make them look better but it requires making the text with double font size and then using css-transform to scale the element to half the size.

If the element is not then absolutely positioned or cropped with overflow:hidden, the flow of the content will behave a bit weirdly.

This is some tiny text 1
This is some tiny text 2